@@ -14,24 +14,27 @@
 #' @import stringr
 #' @import shiny
 #' @import miniUI
+#' @import forcats
 #' @importFrom glue glue
+#' @importFrom hms as.hms
 #' @importFrom data.table data.table
 #' @importFrom data.table :=
 #' @importFrom data.table as.data.table
 #' @importFrom purrr set_names
+#' @importFrom RColorBrewer brewer.pal.info
+#' @importFrom RColorBrewer brewer.pal
 #' @importFrom stats median
 #' @importFrom stats na.omit
 #' @importFrom stats quantile
 #' @importFrom stats sd
+#' @importFrom stats as.formula
 #' @importFrom utils head
 #' @importFrom utils setTxtProgressBar
 #' @importFrom utils txtProgressBar
 #' @importFrom utils data
+#' @importFrom scales rescale
+#' @importFrom plotly ggplotly
+#' @importFrom plotly renderPlotly
+#' @importFrom plotly plotlyOutput
 
-globalVariables(c("case_classifier","consequent","end_case","resource_classifier","antecedent","rel_n","rel_antecedent","rel_consequent",
-				  "timestamp_classifier","ts","aid","case","event","event_classifier","next_event","next_node_id",
-				  "node_id","rel_antecedent","rel_consequent","cum_freq_lag","activity_instance_classifier",
-				  ".N",".","absolute_frequency","as.formula","end","start","reorder","dur",
-				  "start_case","start_relative","trace_id","relative_frequency","cum_freq","com_freq_lag","rank_event"))
-
-NULL
+globalVariables(".")
